Gallery
=======

Below are two examples that have the same code. One has a playback file and thus
is generated with a gif, the other does not have a playback file and is generated
using the sphinx-gallery scraper.
